==> xwidgetsbase-8.7.7.tar.gz: lib/XWidgets/XViewWidgets/XAlertDIalog.dart <==
part of xwidgetbase;

class XAlertDialog extends StatelessWidget {
  String? titleText;
  Function()? onPressedYes;
  Function()? onPressedNo;
  String? labelBTNyes;
  String? labelBTNno;
  Color? colorYes;
  Color? colorNo;
  Color? colorBackGround;

  ///Widget che viene messo sotto il title dell'alert e  sopra l'area dei bottoni in basso
  Widget? childOfAlert;
  double? heightAlertDialog;
  final TextStyle? styleTitle;
  final double? heightActionsBTNArea;

  ///Inseriscici tutti i widget che vuoi che verranno visualizzati in basso
  final Widget? contentActionsBTNArea;
  final EdgeInsetsGeometry? paddingActionsBTNArea;
  final Widget? titleWidget;
  final TextAlign? textAlignTitle;
  XAlertDialog({
    this.titleText,
    this.styleTitle,
    this.onPressedYes,
    this.onPressedNo,
    this.heightActionsBTNArea = 40,
    this.paddingActionsBTNArea,
    this.contentActionsBTNArea,
    this.labelBTNyes,
    this.heightAlertDialog,
    this.labelBTNno,
    this.colorYes,
    this.colorNo,
    this.childOfAlert,
    this.colorBackGround,
    this.titleWidget,
    this.textAlignTitle,
  });

  ///Alert per il trona insietro senza aver salvato
  static alertDialogForPop(BuildContext context, Function()? onPressedYes) {
    return showDialog(
        context: context,
        builder: (context) {
          return XAlertDialog(
            heightAlertDialog: 35,
            styleTitle: XStyles.xStyTextForSubLabel(),
            titleText: "Vuoi annullare le modifiche fatte?",
            labelBTNyes: "SI",
            labelBTNno: "NO",
            colorYes: Colors.greenAccent,
            colorNo: Colors.redAccent,
            onPressedYes: () {
              Navigator.pop(context);
              onPressedYes?.call();
            },
            onPressedNo: () {
              Navigator.pop(context);
            },
          );
        });
  }

  static alertClose(
    BuildContext context, {
    String titleText = "",
    TextStyle? titleStyle,
    Color? titleColor,
    String? labelBTNtext,
    TextStyle? labelBTNstyle,
    Color? labelBTNcolor,
    Decoration? decorationBTN,
    Color? colorBTN,
  }) {
    return showDialog(
        context: context,
        builder: (context) {
          return XAlertDialog(
              heightAlertDialog: null,
              titleText: titleText,
              styleTitle: titleStyle ?? XStyles.xStyTextForTextBase(titleColor ?? Colors.white),
              contentActionsBTNArea: Row(mainAxisAlignment: MainAxisAlignment.end, children: [
                XBtnbase(
                    label: labelBTNtext ?? "CHIUDI",
                    styleLabel: labelBTNstyle ?? XStyles.xStyTextForSubLabel(labelBTNcolor ?? Colors.greenAccent),
                    decorationBTN: decorationBTN ?? BoxDecoration(color: colorBTN ?? Colors.transparent),
                    elevation: 0,
                    onPressed: () {
                      Navigator.pop(context);
                    })
              ]));
        });
  }

  static alertYesNo(
    BuildContext context,
    Function()? onPressedBTN_YES, {
    String titleText = "",
    TextStyle? titleStyle,
    Color? titleColor,
    String? labelBTNtext,
    TextStyle? styleLabelBTN_NO,
    TextStyle? styleLabelBTN_YES,
    Color? colorLabelBTN_NO,
    Color? colorLabelBTN_YES,
    Decoration? decorationBTN,
    Color? colorBTN,
    double? heightBTN,
    double? widthBTN,
  }) {
    return showDialog(
        context: context,
        builder: (context) {
          return XAlertDialog(
              heightAlertDialog: null,
              titleText: titleText,
              styleTitle: titleStyle ?? XStyles.xStyTextForTextBase(titleColor ?? Colors.white),
              contentActionsBTNArea: Row(mainAxisAlignment: MainAxisAlignment.spaceAround, children: [
                XBtnbase(
                    widthBTN: widthBTN ?? 70,
                    heightBTN: heightBTN ?? 30,
                    label: labelBTNtext ?? "NO",
                    styleLabel: styleLabelBTN_NO ?? XStyles.xStyTextForSubLabel(colorLabelBTN_NO ?? Colors.redAccent),
                    decorationBTN: decorationBTN ?? BoxDecoration(color: colorBTN ?? Colors.transparent),
                    elevation: 0,
                    onPressed: () {
                      Navigator.pop(context);
                    }),
                XBtnbase(
                    widthBTN: widthBTN ?? 70,
                    heightBTN: heightBTN ?? 30,
                    label: labelBTNtext ?? "SI",
                    styleLabel: styleLabelBTN_YES ?? XStyles.xStyTextForSubLabel(colorLabelBTN_YES ?? Colors.greenAccent),
                    decorationBTN: decorationBTN ?? BoxDecoration(color: colorBTN ?? Colors.transparent),
                    elevation: 0,
                    onPressed: () {
                      onPressedBTN_YES!();
                      Navigator.pop(context);
                    })
              ]));
        });
  }

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
        contentPadding: paddingActionsBTNArea ?? EdgeInsets.fromLTRB(24.0, 20.0, 24.0, 10.0),
        backgroundColor: colorBackGround,
        title: titleWidget ??
            (heightAlertDialog != null
                ? Container(
                    height: heightAlertDialog,
                    child: Column(
                      children: [
                        titleText != null ? Text(titleText ?? 'Hai cambiato dei dati cosa vuoi fare?', style: styleTitle ?? XStyles.xStyleText(fontSize: 19), textAlign: textAlignTitle ?? TextAlign.left) : Text(titleText ?? "", textAlign: textAlignTitle ?? TextAlign.left),
                        childOfAlert != null ? Container(child: childOfAlert) : Container(height: 1),
                      ],
                    ))
                : Column(
                    children: [
                      titleText != null ? Row(children: [Expanded(child: Text(titleText ?? 'Hai cambiato dei dati cosa vuoi fare?', textAlign: textAlignTitle ?? TextAlign.left, style: styleTitle ?? XStyles.xStyleText(fontSize: 19)))]) : Text(titleText ?? ""),
                      childOfAlert != null ? Container(child: childOfAlert) : Container(height: 1)
                    ],
                  )),
        content: contentActionsBTNArea ??
            Container(
                height: heightActionsBTNArea ?? null,
                child: Row(mainAxisAlignment: MainAxisAlignment.spaceAround, children: [
                  Expanded(child: Container(child: TextButton(onPressed: onPressedNo, child: Text(labelBTNno ?? "NON LI SALVO", style: TextStyle(color: colorNo ?? Colors.redAccent, fontSize: 18))))),
                  Expanded(child: Container(child: TextButton(onPressed: onPressedYes, child: Text(labelBTNyes ?? "LI SALVO", style: TextStyle(color: colorYes ?? Colors.greenAccent, fontSize: 18))))),
                ])));
  }
}

==> xwidgetsbase-10.0.3.tar.gz: lib/XWidgets/XViewWidgets/XAlertDIalog.dart <==
part of xwidgetbase;

class XAlertDialog extends StatelessWidget {
  String? titleText;
  Function()? onPressedYes;
  Function()? onPressedNo;
  String? labelBTNyes;
  String? labelBTNno;
  Color? colorYes;
  Color? colorNo;
  Color? colorBackGround;

  ///Widget che viene messo sotto il title dell'alert e  sopra l'area dei bottoni in basso
  Widget? childOfAlert;
  double? heightAlertDialog;
  final TextStyle? styleTitle;
  final double? heightActionsBTNArea;

  ///Inseriscici tutti i widget che vuoi che verranno visualizzati in basso
  final Widget? contentActionsBTNArea;
  final EdgeInsetsGeometry? paddingActionsBTNArea;
  final Widget? titleWidget;
  final TextAlign? textAlignTitle;
  XAlertDialog({
    this.titleText,
    this.styleTitle,
    this.onPressedYes,
    this.onPressedNo,
    this.heightActionsBTNArea = 40,
    this.paddingActionsBTNArea,
    this.contentActionsBTNArea,
    this.labelBTNyes,
    this.heightAlertDialog,
    this.labelBTNno,
    this.colorYes,
    this.colorNo,
    this.childOfAlert,
    this.colorBackGround,
    this.titleWidget,
    this.textAlignTitle,
  });

  ///Alert per il trona insietro senza aver salvato
  static alertDialogForPop(BuildContext context, Function()? onPressedYes) {
    return showDialog(
        context: context,
        builder: (context) {
          return XAlertDialog(
            heightAlertDialog: 35,
            styleTitle: XStyles.xStyTextForSubLabel(),
            titleText: "Vuoi annullare le modifiche fatte?",
            labelBTNyes: "SI",
            labelBTNno: "NO",
            colorYes: Colors.greenAccent,
            colorNo: Colors.redAccent,
            onPressedYes: () {
              Navigator.pop(context);
              onPressedYes?.call();
            },
            onPressedNo: () {
              Navigator.pop(context);
            },
          );
        });
  }

  static alertClose(
    BuildContext context, {
    String titleText = "",
    TextStyle? titleStyle,
    Color? titleColor,
    String? labelBTNtext,
    TextStyle? labelBTNstyle,
    Color? labelBTNcolor,
    Decoration? decorationBTN,
    Color? colorBTN,
  }) {
    return showDialog(
        context: context,
        builder: (context) {
          return XAlertDialog(
              heightAlertDialog: null,
              titleText: titleText,
              styleTitle: titleStyle ?? XStyles.xStyTextForTextBase(titleColor ?? Colors.white),
              contentActionsBTNArea: Row(mainAxisAlignment: MainAxisAlignment.end, children: [
                XBtnbase(
                    label: labelBTNtext ?? "CHIUDI",
                    styleLabel: labelBTNstyle ?? XStyles.xStyTextForSubLabel(labelBTNcolor ?? Colors.greenAccent),
                    decorationBTN: decorationBTN ?? BoxDecoration(color: colorBTN ?? Colors.transparent),
                    elevation: 0,
                    onPressed: () {
                      Navigator.pop(context);
                    })
              ]));
        });
  }

  static alertYesNo(
    BuildContext context,
    Function()? onPressedBTN_YES, {
    String titleText = "",
    TextStyle? titleStyle,
    Color? titleColor,
    String? labelBTNtext,
    TextStyle? styleLabelBTN_NO,
    TextStyle? styleLabelBTN_YES,
    Color? colorLabelBTN_NO,
    Color? colorLabelBTN_YES,
    Decoration? decorationBTN,
    Color? colorBTN,
    double? heightBTN,
    double? widthBTN,
  }) {
    return showDialog(
        context: context,
        builder: (context) {
          return XAlertDialog(
              heightAlertDialog: null,
              titleText: titleText,
              styleTitle: titleStyle ?? XStyles.xStyTextForTextBase(titleColor ?? Colors.white),
              contentActionsBTNArea: Row(mainAxisAlignment: MainAxisAlignment.spaceAround, children: [
                XBtnbase(
                    widthBTN: widthBTN ?? 70,
                    heightBTN: heightBTN ?? 30,
                    label: labelBTNtext ?? "NO",
                    styleLabel: styleLabelBTN_NO ?? XStyles.xStyTextForSubLabel(colorLabelBTN_NO ?? Colors.redAccent),
                    decorationBTN: decorationBTN ?? BoxDecoration(color: colorBTN ?? Colors.transparent),
                    elevation: 0,
                    onPressed: () {
                      Navigator.pop(context);
                    }),
                XBtnbase(
                    widthBTN: widthBTN ?? 70,
                    heightBTN: heightBTN ?? 30,
                    label: labelBTNtext ?? "SI",
                    styleLabel: styleLabelBTN_YES ?? XStyles.xStyTextForSubLabel(colorLabelBTN_YES ?? Colors.greenAccent),
                    decorationBTN: decorationBTN ?? BoxDecoration(color: colorBTN ?? Colors.transparent),
                    elevation: 0,
                    onPressed: () {
                      onPressedBTN_YES!();
                      Navigator.pop(context);
                    })
              ]));
        });
  }

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      contentPadding: paddingActionsBTNArea ?? EdgeInsets.fromLTRB(24.0, 20.0, 24.0, 10.0),
      backgroundColor: colorBackGround,
      title: titleWidget ??
          Column(children: [
            titleText != null ? Text(titleText ?? 'Hai cambiato dei dati cosa vuoi fare?', style: styleTitle ?? XStyles.xStyleText(fontSize: 19), textAlign: textAlignTitle ?? TextAlign.left) : Text(titleText ?? "", textAlign: textAlignTitle ?? TextAlign.left),
          ]),
      content: childOfAlert != null
          ? (heightAlertDialog != null
              ? Container(height: heightAlertDialog, child: childOfAlert)
              : Column(
                  children: [childOfAlert!],
                ))
          : Container(height: 1),
      actions: [
        contentActionsBTNArea ??
            Container(
                height: heightActionsBTNArea ?? null,
                child: Row(mainAxisAlignment: MainAxisAlignment.spaceAround, children: [
                  Expanded(child: Container(child: TextButton(onPressed: onPressedNo, child: Text(labelBTNno ?? "NON LI SALVO", style: TextStyle(color: colorNo ?? Colors.redAccent, fontSize: 18))))),
                  Expanded(child: Container(child: TextButton(onPressed: onPressedYes, child: Text(labelBTNyes ?? "LI SALVO", style: TextStyle(color: colorYes ?? Colors.greenAccent, fontSize: 18))))),
                ])),
      ],
    );
  }
}
